Roadmap for future versions
===========================

[ ] Bugfix # 88 Using hyperlinks causes charts to break

[ ] Bugfix # 95 add row height and col width functionality

[ ] Bugfix # 97 adds pie charts and combination charts

[ ] Bugfix # 99 adds ticks around multi-word titles in chart references

[ ] Bugfix # 103

[ ] Bugfix # 152

[ ] Bugfix # 163

[ ] Bugfix # 172

[ ] Bugfix # 181

[ ] Bugfix # 184 support for right-to-left

[ ] Bugfix # 215 roundtrip sheetviews

[ ] Move all tests from /tests to relevant modules

[ ] Support named styles

[ ] Different, faster solution for immutable styles: either swap the class or use a proxy

[ ] Expose formatting objects directly, Style as namedtuple

[ ] Cleanup API and inheritance of IterableWorksheet / Worksheet

[ ] Improve handling of relationships

[ ] Do not write cached values for charts

[ ] Support cells with formulae in charts

[ ] Merge existing patches for charts

[ ] Default to using an iterator when working with charts?

[ ] Simplify Chart API

[ ] Support cell type "d" with W3C formatting

[ ] Make worksheets iterable (by row)

[ ] Implement workbook properties using descriptors and dictionary interface

[x] Both cell coordinate lookups as dict

[ ] Group utility functions in a single module
